==> sammaadmin-1.00.tar.gz: htdocs/user/postldapadmin/samma/index.php <==
<?php

/*
 * postLDAPadmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * 桼SaMMA԰
 *
 * $RCSfile: index.php,v $
 * $Revision: 1.7 $
 * $Date: 2010/06/29 10:11:10 $
 **********************************************************/

include_once("../../initial");
include_once("lib/dglibpostldapadmin");
include_once("lib/dglibcommon");
include_once("lib/dglibpage");
include_once("lib/dglibsess");
include_once("lib/dglibldap");
include_once("lib/dglibsamma");

/********************************************************
ƥڡ
*********************************************************/

define("OPERATION", "Ź沽");

/***********************************************************
 * 饹: ˥塼
 **********************************************************/
Class my_page extends page {

    /***********************************************************
     * ܥǥɽʥС饤ɡ
     **********************************************************/
    function display_body() {
        global $sesskey;

        print<<<EOD

<script type="text/javascript">
<!--
function allSubmit(url, domname) {
    document.all.action = url;
    document.all.domname.value = domname;
    document.all.submit();
}
// -->
</script>

<form name="all" action="index.php" method="post">
  <div><b>ԤȤǧ᡼륢ɥ쥹/ɥᥤΰǤ</b></div>

  <br>
  <table class="table">
    <tbody>
      <tr>
        <td class="search_check"></td>
        <td class="search_name">ԥɥᥤ/᡼륢ɥ쥹</td>
        <td class="search_status">Ź沽ѥ</td>
        <td class="search_status">Ź沽롼</td>
        <td class="search_ref"></td>
EOD;
        /* ɽ */
        print_result();

        print<<<EOD
      </tr>
    </tbody>
  </table>
  <br>
  <input type="submit" name="new_add" value="" class="new_add_btn">
  <input type="submit" name="check_del" value="" class="check_del_btn" onClick="return msgConfirm('åޤ\\nǤ')">
  <input type="hidden" name="sk" value="$sesskey">
</form>
EOD;

    }

};

/*********************************************************
 * print_result
 *
 * ɽ
 *
 * []
 *       ʤ
 *
 * [֤]
 *       ʤ
 **********************************************************/
function print_result()
{
    global $rp_data;
    global $del_list;

    /* ǡʤ϶ɽ */
    if (is_array($rp_data) === FALSE) {
        return;
    }

    /*  */
    uksort($rp_data, DOMAIN_SORT);

    /* ɽ */
    foreach ($rp_data as $key => $value) {
        /*  */
        $rule = DISP_EFFECT;
        $passwd = DISP_RANDOM;
        $domain = $key;

        /* ѥ */
        if ($value != "") {
            $passwd = DISP_INDIVI;
        }

        /* Ź沽롼 */
        $str = explode("!", $key, 2);
        if ($str[0] != $key) {
            $domain = $str[1];
            $rule = DISP_INEFFECT;
            $passwd = DISP_NOPASS;
        }

        $checked = "";
        /* ݻ */
        if (is_array($del_list) === TRUE) {
            foreach($del_list as $delval) {
                if ($delval == $key) {
                    $checked = "checked";
                }
            }
        }

        /*  */
        $domain = htmlspecialchars($domain);
        $cnv_key = str_replace("'", "\'", $key);

        print<<<EOD
      <tr>
        <td class="value"><input type="checkbox" name="delete[]" value="$key" $checked></td>
        <td class="value">$domain</td>
        <td class="value">$passwd</td>
        <td class="value_center">$rule</td>

        <td class="value_center"><input type="button" class="list_mod_btn" onClick="allSubmit('samma_mod.php', '$cnv_key')" title="Խ"></td>

      </tr>
EOD;
    }
        print<<<EOD

        <input type="hidden" name="domname" value="">
EOD;

    return;

}

/***********************************************************
 * 
 **********************************************************/

/* 󥹥󥹺 */
$pg = new my_page();
if (isset ($_POST["sk"]) === TRUE) {
    $sesskey = $_POST["sk"];
}

/* ե롢ִեɹåå */
$ret = user_init();
if ($ret === FALSE) {
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}

/* å */
if (isset($_POST["msg"]) === TRUE) {
    $err_msg = htmlspecialchars($_POST["msg"]);
}

/***********************************************************
 * main
 **********************************************************/
/* 桼̾Ǽ */
$user = $env['loginuser'];
$userdn = $env['user_selfdn'];

/* 桼μ */
$ret = get_userdata ($userdn);
if ($ret === FALSE) {
    result_log(OPERATION . ":NG:" . $err_msg);
    $err_msg = "桼μ˼Ԥޤ";
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}

$dispusr = $web_conf[$url_data['script']]['displayuser'];
$dispusr = htmlspecialchars($ldapdata[0][$dispusr][0]);

/* ݻͼ */
$del_list = "";
if (isset($_POST["delete"]) === TRUE) {
    $del_list = $_POST["delete"];
}

/* ʬ */
/* ɲ */
if (isset($_POST["new_add"]) === TRUE) {
    /* ɲò̤ */
    page_location("samma_add.php", $del_list);
    exit (0);

/* åΤ */
} elseif (isset($_POST["check_del"]) === TRUE) {
    /* åʤ */
    if (isset($_POST["delete"]) === FALSE) {
        $err_msg = "оݤ򤵤Ƥޤ";
    } else {
        /* 桼ǤΥХɤ̵ */
        $env['user_self'] = FALSE;

        /* ɥᥤ/᡼륢ɥ쥹κ */
        $ret = ldap_enc_del($userdn, $_POST["delete"]);
        /* оݤʤ顼̾泌顼 */
        if ($ret === LDAP_ERR_NODATA) {
            $err_msg = "" . $err_msg;
            result_log(OPERATION . ":NG:" . $err_msg);
            /* ä */
            if ($suc_msg != "") {
                $suc_msg = "" . $suc_msg;
                result_log(OPERATION . ":OK:" . $suc_msg);
                $err_msg .= "<br>" . $suc_msg;
            }
        /* 顼ϥƥ२顼 */
        } elseif ($ret!== LDAP_OK) {
            result_log(OPERATION . ":NG:" . $err_msg);
            /* 桼ѥåѹ */
            $delete = implode(", ", $_POST["delete"]);
            $err_msg = "κ˼Ԥޤ(" . $delete . ")";
            $sys_err = TRUE;
            $pg->display(CONTENT);
            exit (1);
        /*  */
        } else {
            $err_msg = "" . $suc_msg;
            result_log(OPERATION . ":OK:" . $err_msg);
        }

    }
}

/*  */
$rp_data = "";
/* 桼ǤΥХɤ̵ */
$env['user_self'] = FALSE;
$ret = get_user_data($userdn, $rp_data);
if ($ret === FALSE) {
    result_log(OPERATION . ":NG:" . $err_msg);
    $err_msg = "Ź沽μ˼Ԥޤ";
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}

/***********************************************************
 * ɽ
 **********************************************************/

/* ڡν */
$pg->display(CONTENT);

?>

==> sammaadmin-2.00.tar.gz: htdocs/user/postldapadmin/samma/index.php <==
<?php

/*
 * postLDAPadmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * 桼SaMMA԰
 *
 * $RCSfile: index.php,v $
 * $Revision: 1.9 $
 * $Date: 2013/08/22 09:32:08 $
 **********************************************************/

include_once("../../initial");
include_once("lib/dglibpostldapadmin");
include_once("lib/dglibcommon");
include_once("lib/dglibpage");
include_once("lib/dglibsess");
include_once("lib/dglibldap");
include_once("lib/dglibsamma");

/********************************************************
ƥڡ
*********************************************************/

define("TMPLFILE", "samma/samma_user_menu.tmpl");
define("OPERATION", "Ź沽");

/***********************************************************
 * ؿ
 **********************************************************/
/*********************************************************
 * print_result
 *
 * ɽ
 *
 * []
 *      $tag  ֤ 
 *
 * [֤]
 *       ʤ
 **********************************************************/
function print_result(&$looptag)
{
    global $rp_data;
    global $del_list;

    /* ɥᥤ */
    $domain_count = 0;

    /* ǡʤ϶ɽ */
    if (is_array($rp_data) === FALSE) {
        $looptag = array();
        return;
    }

    /*  */
    uksort($rp_data, DOMAIN_SORT);

    /* ɽ */
    foreach ($rp_data as $key => $value) {
        /*  */
        $rule = DISP_EFFECT;
        $passwd = DISP_RANDOM;
        $domain = $key;

        /* ѥ */
        if ($value != "") {
            $passwd = DISP_INDIVI;
        }

        /* Ź沽롼 */
        $str = explode("!", $key, 2);
        if ($str[0] != $key) {
            $domain = $str[1];
            $rule = DISP_INEFFECT;
            $passwd = DISP_NOPASS;
        }

        /*  */
        $domain = htmlspecialchars($domain);
        $cnv_key = str_replace("'", "\'", $key);

        $looptag[$domain_count]["<<KEY>>"] = $key;
        $looptag[$domain_count]["<<DOMAIN>>"] = $domain;
        $looptag[$domain_count]["<<PASSWD>>"] = $passwd;
        $looptag[$domain_count]["<<RULE>>"] = $rule;
        $looptag[$domain_count]["<<MOD_BTN>>"] = <<<EOD
<input type="button" class="list_mod_btn" onClick="allSubmit('samma_mod.php', '$cnv_key')" title="Խ">

EOD;
        $domain_count++;
    }
    return TRUE;

}

/***********************************************************
 * 
 **********************************************************/
$tag = array();
$looptag = array();

/* å󥭡ѿ */
if (isset ($_POST["sk"]) === TRUE) {
    $sesskey = $_POST["sk"];
}

/* ե롢ִեɹåå */
$ret = user_init();
if ($ret === FALSE) {
    syserr_display();
    exit (1);
}

/* å */
if (isset($_POST["msg"]) === TRUE) {
    $err_msg = htmlspecialchars($_POST["msg"]);
}

/***********************************************************
 * main
 **********************************************************/
/* 桼̾Ǽ */
$user = $env['loginuser'];
$userdn = $env['user_selfdn'];

/* 桼μ */
$ret = get_userdata($userdn);
if ($ret === FALSE) {
    result_log(OPERATION . ":NG:" . $err_msg);
    $err_msg = "桼μ˼Ԥޤ";
    syserr_display();
    exit (1);
}

$dispusr = $web_conf[$url_data['script']]['displayuser'];
$dispusr = htmlspecialchars($ldapdata[0][$dispusr][0]);

/* ݻͼ */
$del_list = "";
if (isset($_POST["delete"]) === TRUE) {
    $del_list = $_POST["delete"];
}

/* ʬ */
/* ɲ */
if (isset($_POST["new_add"]) === TRUE) {
    /* ɲò̤ */
    dgp_location("samma_add.php", $del_list);
    exit (0);

/* åΤ */
} elseif (isset($_POST["check_del"]) === TRUE) {
    /* åʤ */
    if (isset($_POST["delete"]) === FALSE) {
        $err_msg = "оݤ򤵤Ƥޤ";
    } else {
        /* 桼ǤΥХɤ̵ */
        $env['user_self'] = FALSE;

        /* ɥᥤ/᡼륢ɥ쥹κ */
        $ret = ldap_enc_del($userdn, $_POST["delete"]);
        /* оݤʤ顼̾泌顼 */
        if ($ret === LDAP_ERR_NODATA) {
            $err_msg = "" . $err_msg;
            result_log(OPERATION . ":NG:" . $err_msg);
            /* ä */
            if ($suc_msg != "") {
                $suc_msg = "" . $suc_msg;
                result_log(OPERATION . ":OK:" . $suc_msg);
                $err_msg .= "<br>" . $suc_msg;
            }
        /* 顼ϥƥ२顼 */
        } elseif ($ret !== LDAP_OK) {
            result_log(OPERATION . ":NG:" . $err_msg);
            /* 桼ѥåѹ */
            $delete = implode(", ", $_POST["delete"]);
            $err_msg = "κ˼Ԥޤ(" . $delete . ")";
            syserr_display();
            exit (1);
        /*  */
        } else {
            $err_msg = "" . $suc_msg;
            result_log(OPERATION . ":OK:" . $err_msg);
        }

    }
}

/*  */
$rp_data = "";
/* 桼ǤΥХɤ̵ */
$env['user_self'] = FALSE;
$ret = get_user_data($userdn, $rp_data);
if ($ret === FALSE) {
    result_log(OPERATION . ":NG:" . $err_msg);
    $err_msg = "Ź沽μ˼Ԥޤ";
    syserr_display();
    exit (1);
}

/***********************************************************
 * ɽ
 **********************************************************/
/* ̤Υ */
set_tag_common($tag);

/* ̤֤ */
print_result($looptag);

/* ڡν */
$ret = display(TMPLFILE, $tag, $looptag, STARTTAG, ENDTAG);
if ($ret === FALSE) {
    result_log($log_msg, LOG_ERR);
    syserr_display();
    exit(1);
}

?>
